@@ -176,7 +176,7 @@ class _E2EConfigClient(object):
         for zone_name in zone_dns_name_guesses:
             # get the zone id
                 logger.debug("looking for zone: %s", zone_name)
-                matches = [domain for domain in domains if domain.name == zone_name]
+                matches = [domain for domain in domains if domain['domain_name'] == zone_name]
 
                 if matches:
                     domain = matches[0]
